!----------------------------------------------------------------------------------------------------------------------------------!
SUBROUTINE cbem_lap_init
!----------------------------------------------------------------------------------------------------------------------------------!

!===purpose===! 

!**********************************************************************************************************************************!
!********************************  COLLOCATION BEM for 3D LAPLACE EQUATION: SINGULAR FORMULATION  *********************************!
!***************************************  3-NODED TRIANGULAR ELEMENT: ANALYTIC INTEGRATION  ***************************************!
!***********************************************  PIECEWISE CONSTANT APPROXIMATION  ***********************************************!
!***********************************************  Initialize arrays and parameters  ***********************************************!
!**********************************************************************************************************************************!

!*** Developer: Sylvain Nintcheu Fata
!*** Version:   V.1.3
!*** Released:  Jun 14, 2012

 
USE KINDS
USE PARAMS,   ONLY: fac,pi,pix2 ! pi = 3.1415926535897932, pix2 = 2*pi, fac == Factor of the Green's function: fac = 1/(4*pi)
USE SRF_GEOM, ONLY: nbelt,belt  ! nbelt == Total number of boundary elements
                                ! belt(i,k) == Global index of the i-th node on the boundary element k, i=1,2,3
USE SRF_GEOM, ONLY: bnd,repnd   ! bnd(:,k) == Cartesian coordinates of the k-th boundary node
                                ! repnd(:,k) == Cartesian coordinates of the centroid of the k-th boundary element


IMPLICIT NONE

 integer(kind=k9) :: k,alloc_st



   pi = 4.0_dp*datan(1.0_dp) ! pi = 3.1415926535897932
   pix2 = 2.0_dp*pi
   fac = 1.0_dp/(4.0_dp*pi)  ! fac == Factor of the Green's function
   
    allocate(repnd(3,nbelt),STAT=alloc_st)
    if ( alloc_st == 0 ) then ! If repnd is successfully allocated
!*** Determine representative nodes for each boundary element *************************************!
          loop0: do k=1,nbelt ! loop over all boundary elements (element = flat triangle)
              !*** repnd(:,k) == Centroid (representative node) of the k-th boundary triangle
	      repnd(1,k) = (bnd(1,belt(1,k)) + bnd(1,belt(2,k)) + bnd(1,belt(3,k)))/3.0_dp
              repnd(2,k) = (bnd(2,belt(1,k)) + bnd(2,belt(2,k)) + bnd(2,belt(3,k)))/3.0_dp
              repnd(3,k) = (bnd(3,belt(1,k)) + bnd(3,belt(2,k)) + bnd(3,belt(3,k)))/3.0_dp
          enddo loop0
!*** End Determine representative nodes for each boundary element *********************************!
    else
          write(*,*)'cbem_lap_init: Allocate array "repnd" failed with Status=',alloc_st
	  stop
    endif

!----------------------------------------------------------------------------------------------------------------------------------!
END SUBROUTINE cbem_lap_init
!----------------------------------------------------------------------------------------------------------------------------------!
