!----------------------------------------------------------------------------------------------------------------------------------!
SUBROUTINE cbem_poi_srf_eval(InfParams,InfData,tm0)
!----------------------------------------------------------------------------------------------------------------------------------!

!===purpose===! 

!**********************************************************************************************************************************!
!********************************  COLLOCATION BEM for 3D POISSON EQUATION: SINGULAR FORMULATION  *********************************!
!************************************  3-NODED TRIANGULAR ELEMENT: SEMI-ANALYTIC INTEGRATION  *************************************!
!***********************************************  PIECEWISE CONSTANT APPROXIMATION  ***********************************************!
!***************************************  Solve the Singular BIE for the Poisson equation  ****************************************!
!**********************************************************************************************************************************!

!*** Developer: Sylvain Nintcheu Fata
!*** Version:   V.1.1
!*** Released:  Aug 21, 2012

 
USE KINDS


IMPLICIT NONE

 real(kind=dp), intent(in) :: tm0 ! Initial time

 character(len=72) :: InfParams,InfData
 real(kind=dp) :: tm1 ! time variable



    write(*,100)' >>>  COLLOCATION BEM for 3D POISSON EQUATION: SINGULAR FORMULATION ==> CBEM_POI <== Version 1.1  <<<'

    write(*,100)' >>>  Data Input & Initializations  <<<'
     call cbem_poi_input(InfParams,InfData) ! Read input data and parameters
     call cbem_lap_init ! Initialize arrays and parameters
    call cpu_time(tm1) ! Current time
    write(*,*)'Time == ',tm1-tm0,'s'

    write(*,100)' >>>  Assembly of the Discretized BIE  <<<'   
     call cbem_poi_assem ! Assemble h and g influence matrices and the contributions of the source term
    call cpu_time(tm1) ! Current time
    write(*,*)'Time == ',tm1-tm0,'s'

    write(*,100)' >>>  Left-hand side & Right-hand side of the Discretized BIE  <<<'
     call cbem_poi_lrhs ! Form the left- and right-hand sides of the discretized BIE
    call cpu_time(tm1) ! Current time
    write(*,*)'Time == ',tm1-tm0,'s'
  
    write(*,100)' >>>  Solution of the Discretized BIE  <<<'          
     call cbem_lap_solv ! Solve the Discretized BIE


  100 format (1x, a)

!----------------------------------------------------------------------------------------------------------------------------------!
END SUBROUTINE cbem_poi_srf_eval
!----------------------------------------------------------------------------------------------------------------------------------!
